#include "2MASS.h"

#define NR_END 1
#define FREE_ARG char*


void nrerror(char error_text[])
{
        fprintf(stderr,"%s\n",error_text);
        fprintf(stderr,"...now exiting to system...\n");
        exit(1);
}

enregistrement *enrvector(long nl, long nh)
/* allocate an enregistrement vector with subscript range v[nl..nh] */
{
        enregistrement *v;

        v=(enregistrement *)malloc((size_t) ((nh-nl+1+NR_END)*sizeof(enregistrement)));
        if (!v) nrerror("allocation failure in enrvector()");
        return v-nl+NR_END;
}

position *posvector(long nl, long nh)
/* allocate an position vector with subscript range v[nl..nh] */
{
        position *v;

        v=(position *)malloc((size_t) ((nh-nl+1+NR_END)*sizeof(position)));
        if (!v) nrerror("allocation failure in posvector()");
        return v-nl+NR_END;
}

int *ivector(long nl, long nh)
/* allocate an int vector with subscript range v[nl..nh] */
{
        int *v;

        v=(int *)malloc((size_t) ((nh-nl+1+NR_END)*sizeof(int)));
        if (!v) nrerror("allocation failure in ivector()");
        return v-nl+NR_END;
}

long *lvector(long nl, long nh)
/* allocate a long vector with subscript range v[nl..nh] */
{
        long *v;

        v=(long *)malloc((size_t) ((nh-nl+1+NR_END)*sizeof(long)));
        if (!v) nrerror("allocation failure in lvector()");
        return v-nl+NR_END;
}

unsigned long *ulvector(long nl, long nh)
/* allocate a unsigned long vector with subscript range v[nl..nh] */
{
        unsigned long *v;

        v=(unsigned long *)malloc((size_t) ((nh-nl+1+NR_END)*sizeof(unsigned long)));
        if (!v) nrerror("allocation failure in ulvector()");
        return v-nl+NR_END;
}

float *vector(long nl, long nh)
/* allocate a float vector with subscript range v[nl..nh] */
{
        float *v;

        v=(float *)malloc((size_t) ((nh-nl+1+NR_END)*sizeof(float)));
        if (!v) nrerror("allocation failure in vector()");
        return v-nl+NR_END;
}

double *dvector(long nl, long nh)
/* allocate an double vector with subscript range v[nl..nh] */
{
        double *v;

        v=(double *)malloc((size_t) ((nh-nl+1+NR_END)*sizeof(double)));
        if (!v) nrerror("allocation failure in dvector()");
        return v-nl+NR_END;
}

void free_ivector(int *v, long nl, long nh)
/* free an int vector allocated with ivector() */
{
        free((FREE_ARG) (v+nl-NR_END));
}


void free_lvector(long *v, long nl, long nh)
/* free a long vector allocated with lvector() */
{
        free((FREE_ARG) (v+nl-NR_END));
}

void free_ulvector(unsigned long *v, long nl, long nh)
/* free a unsigned long vector allocated with lvector() */
{
        free((FREE_ARG) (v+nl-NR_END));
}

void free_vector(float *v, long nl, long nh)
/* free a float vector allocated with vector() */
{
        free((FREE_ARG) (v+nl-NR_END));
}

void free_dvector(double *v, long nl, long nh)
/* free a double vector allocated with dvector() */
{
        free((FREE_ARG) (v+nl-NR_END));
}

void free_posvector(position *v, long nl, long nh)
/* free an position vector allocated with posvector() */
{
        free((FREE_ARG) (v+nl-NR_END));
}

void free_enrvector(enregistrement *v, long nl, long nh)
/* free an enregistrement vector allocated with enrvector() */
{
        free((FREE_ARG) (v+nl-NR_END));
}

